# remirepo/fedora spec file for php-tecnickcom-tc-lib-pdf-filter
#
# Copyright (c) 2015-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    c57fdde0e389df0bc6d3cc2d9531057dcfb0e82b
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-pdf-filter
%global php_project  %{_datadir}/php/Com/Tecnick/Pdf/Filter
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        1.4.7
Release:        1%{?dist}
Summary:        PHP library to decode PDF compression and encryption filters

License:        LGPLv3+
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
%if 0%{?fedora} >= 32 || 0%{?rhel} >= 9
%global phpunit %{_bindir}/phpunit9
BuildRequires:  phpunit9 >= 9.5.0
%else
%global phpunit %{_bindir}/phpunit8
BuildRequires:  phpunit8 >= 8.5.13
%endif
BuildRequires:  php(language) >= 5.4
Requires:       php-pcre
Requires:       php-zlib
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": ">=5.4",
#        "ext-zlib": "*",
#        "ext-pcre": "*"
Requires:       php(language) >= 5.4
Requires:       php-pcre
Requires:       php-zlib
# From phpcompatinfo report for version 1.3.4
# none
Requires:       php-composer(fedora/autoloader)

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library to decode PDF compression and encryption filters.

The initial source code has been extracted from TCPDF (http://www.tcpdf.org).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Sanity check
grep -q '^%{version}$' VERSION


%build
phpab --template fedora --output src/autoload.php src


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in "php %{phpunit}" php74 php80 php81; do
   if which $cmdarg; then
      set $cmdarg
      $1 ${2:-%{_bindir}/phpunit9} --no-coverage --verbose || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc README.md
%dir %{_datadir}/php/Com
%dir %{_datadir}/php/Com/Tecnick
%dir %{_datadir}/php/Com/Tecnick/Pdf
%{php_project}


%changelog
* Mon Jan  3 2022 Remi Collet <remi@remirepo.net> - 1.4.7-1
- update to 1.4.7 (no change)

* Mon Feb  8 2021 Remi Collet <remi@remirepo.net> - 1.4.4-1
- update to 1.4.4 (no change)

* Mon Dec 21 2020 Remi Collet <remi@remirepo.net> - 1.4.1-1
- update to 1.4.1
- switch to classmap autoloader

* Fri Jan  3 2020 Remi Collet <remi@remirepo.net> - 1.3.11-1
- update to 1.3.11 (no change)

* Thu Jan  2 2020 Remi Collet <remi@remirepo.net> - 1.3.10-1
- update to 1.3.10 (no change)

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.3.9-1
- update to 1.3.9

* Mon Jun 25 2018 Remi Collet <remi@remirepo.net> - 1.3.8-1
- update to 1.3.8 (no change)

* Mon May 14 2018 Remi Collet <remi@remirepo.net> - 1.3.7-1
- update to 1.3.7 (no change)
- switch to phpunit7

* Tue Jan  2 2018 Remi Collet <remi@remirepo.net> - 1.3.6-1
- Update to 1.3.6 (no change)

* Sun Feb 12 2017 Remi Collet <remi@remirepo.net> - 1.3.5-1
- update to 1.3.5 (no change)

* Mon Feb  6 2017 Remi Collet <remi@remirepo.net> - 1.3.4-1
- update to 1.3.4 (no change)

* Fri Sep  2 2016 Remi Collet <remi@fedoraproject.org> - 1.3.3-1
- update to 1.3.3 (no change)

* Tue Jun 14 2016 Remi Collet <remi@fedoraproject.org> - 1.3.0-1
- update to 1.3.0 (no change)

* Fri Mar  4 2016 Remi Collet <remi@fedoraproject.org> - 1.2.1-1
- update to 1.2.1 (no change)

* Fri Dec 11 2015 Remi Collet <remi@fedoraproject.org> - 1.2.0-1
- update to 1.2.0 (no change)
- raise dependency on php >= 5.4

* Fri Dec 11 2015 Remi Collet <remi@fedoraproject.org> - 1.1.24-1
- update to 1.1.24 (no change)

* Mon Dec  7 2015 Remi Collet <remi@fedoraproject.org> - 1.1.22-1
- update to 1.1.22 (no change)

* Thu Dec  3 2015 Remi Collet <remi@fedoraproject.org> - 1.1.20-1
- update to 1.1.20 (no change)

* Fri Nov 27 2015 Remi Collet <remi@fedoraproject.org> - 1.1.19-1
- update to 1.1.19 (no change)

* Wed Nov 25 2015 Remi Collet <remi@fedoraproject.org> - 1.1.18-1
- update to 1.1.18 (no change)

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 1.1.14-1
- update to 1.1.14 (no change)

* Fri Nov 20 2015 Remi Collet <remi@fedoraproject.org> - 1.1.12-1
- update to 1.1.12 (no change)

* Wed Nov 18 2015 Remi Collet <remi@fedoraproject.org> - 1.1.9-1
- update to 1.1.9 (no change)
- run test suite with both PHP 5 and 7 when available

* Tue Oct 20 2015 Remi Collet <remi@fedoraproject.org> - 1.1.8-1
- update to 1.1.8 (no change)

* Fri Sep 25 2015 Remi Collet <remi@fedoraproject.org> - 1.1.7-1
- update to 1.1.7 (no change)

* Sun Sep 13 2015 Remi Collet <remi@fedoraproject.org> - 1.1.4-1
- update to 1.1.4
- provide php-composer(tecnickcom/tc-lib-pdf-filter)

* Fri Jul 24 2015 Remi Collet <remi@fedoraproject.org> - 1.1.3-1
- update to 1.1.3 (no change)

* Thu Jul  2 2015 Remi Collet <remi@fedoraproject.org> - 1.1.1-1
- update to 1.1.1
- drop patch merged upstream

* Thu Jul  2 2015 Remi Collet <remi@fedoraproject.org> - 1.1.0-1
- initial package, version 1.1.0
- open https://github.com/tecnickcom/tc-lib-pdf-filter/pull/1
  fix autoloader

